@@ -269,7 +269,7 @@ int xsane_back_gtk_make_path(size_t buf_size, char *buf, const char *prog_name,
   {
     snprintf(buf, buf_size-2, "%s", STRINGIFY(PATH_SANE_DATA_DIR));
   }
-  else /* make path to temporary file */
+  else /* make path to temporary file XSANE_PATH_TMP */
   {
     snprintf(buf, buf_size-2, "%s", preferences.tmp_path);
   }
@@ -406,7 +406,7 @@ int xsane_back_gtk_make_path(size_t buf_size, char *buf, const char *prog_name,
 
   if (location == XSANE_PATH_TMP) /* tmp dir, add uid */
   {
-   char tmpbuf[256];
+   char tmpbuf[TEXTBUFSIZE];
    uid_t uid;
    int fd;
 
@@ -469,7 +469,7 @@ void xsane_back_gtk_set_option(int opt_num, void *val, SANE_Action action)
 {
  SANE_Status status;
  SANE_Int info;
- char buf[256];
+ char buf[TEXTBUFSIZE];
  int old_colors = xsane.xsane_colors;
  int update_gamma = FALSE;
 
@@ -789,12 +789,12 @@ gint xsane_back_gtk_decision(gchar *title, gchar **xpm_d,  gchar *message, gchar
 
 void xsane_back_gtk_ipc_dialog_callback(gpointer data, gint source, GdkInputCondition cond)
 {
- char message[256];
+ char message[TEXTBUFSIZE];
  size_t bytes;
 
   DBG(DBG_proc, "xsane_back_gtk_message\n");
 
-  bytes = read(xsane.ipc_pipefd[0], message, 255);
+  bytes = read(xsane.ipc_pipefd[0], message, sizeof(message)-1);
   message[bytes] = 0;
 
   xsane_back_gtk_decision(ERR_HEADER_CHILD_PROCESS_ERROR, (gchar **) error_xpm, message, BUTTON_CLOSE, 0 /* no reject text */, FALSE);
@@ -877,7 +877,7 @@ char *fileselection_filetype = NULL;
 static void xsane_back_gtk_filetype_callback(GtkWidget *widget, gpointer data)
 {
  char *extension, *filename;
- char buffer[256];
+ char buffer[PATH_MAX];
  char *new_filetype = (char *) data;
 
   DBG(DBG_proc, "xsane_filetype_callback\n");
@@ -1302,7 +1302,7 @@ static gint xsane_back_gtk_autobutton_update(GtkWidget *widget, DialogElement *e
  const SANE_Option_Descriptor *opt;
  SANE_Status status;
  SANE_Word val;
- char buf[256];
+ char buf[TEXTBUFSIZE];
 
   DBG(DBG_proc, "xsane_back_gtk_autobutton_update\n");
 
@@ -1466,7 +1466,7 @@ static void xsane_back_gtk_value_update(GtkAdjustment *adj_data, DialogElement *
 
 static void xsane_back_gtk_range_display_value_right_callback(GtkAdjustment *adjust, gpointer data)
 {
- gchar buf[256];
+ gchar buf[TEXTBUFSIZE];
  int digits = (int) data;
  GtkLabel *label;
  
@@ -2138,7 +2138,7 @@ void xsane_set_sensitivity(SANE_Int sensitivity)
 {
   DBG(DBG_proc, "xsane_set_sensitivity(%d)\n", sensitivity);
 
-  if (xsane.shell)
+  if (xsane.dialog)
   {
     /* clear or rebuild histogram */
     if (sensitivity)
@@ -2154,8 +2154,8 @@ void xsane_set_sensitivity(SANE_Int sensitivity)
     gtk_widget_set_sensitive(xsane.menubar, sensitivity); 
     gtk_widget_set_sensitive(xsane.xsane_window, sensitivity); 
     gtk_widget_set_sensitive(GTK_WIDGET(xsane.start_button), sensitivity);
-    gtk_widget_set_sensitive(xsane.standard_options_shell, sensitivity);
-    gtk_widget_set_sensitive(xsane.advanced_options_shell, sensitivity);
+    gtk_widget_set_sensitive(xsane.standard_options_dialog, sensitivity);
+    gtk_widget_set_sensitive(xsane.advanced_options_dialog, sensitivity);
     gtk_widget_set_sensitive(xsane.histogram_dialog, sensitivity);
 #ifdef HAVE_WORKING_GTK_GAMMACURVE
     gtk_widget_set_sensitive(xsane.gamma_dialog, sensitivity);
@@ -2172,22 +2172,13 @@ void xsane_set_sensitivity(SANE_Int sensitivity)
     gtk_widget_set_sensitive(xsane.preview->start, sensitivity);        /* Acquire preview button */
   }
 
-  if (xsane.fax_dialog)
+  if (xsane.project_dialog)
   {
-    /* do not change sensitivity of fax_dialog, we want the progress bar */
+    /* do not change sensitivity of project_dialog, we want the progress bar */
     /* to be sensitive */
-    gtk_widget_set_sensitive(xsane.fax_project_box, sensitivity);
-    gtk_widget_set_sensitive(xsane.fax_project_exists, sensitivity);
-    gtk_widget_set_sensitive(xsane.fax_project_entry_box, sensitivity);
-  }
-
-  if (xsane.mail_dialog)
-  {
-    /* do not change sensitivity of mail_dialog, we want the progress bar */
-    /* to be sensitive */
-    gtk_widget_set_sensitive(xsane.mail_project_box, sensitivity);
-    gtk_widget_set_sensitive(xsane.mail_project_exists, sensitivity);
-    gtk_widget_set_sensitive(xsane.mail_project_entry_box, sensitivity);
+    gtk_widget_set_sensitive(xsane.project_box, sensitivity);
+    gtk_widget_set_sensitive(xsane.project_exists, sensitivity);
+    gtk_widget_set_sensitive(xsane.project_entry_box, sensitivity);
   }
 
   if (xsane.batch_scan_dialog)
