@@ -81,7 +81,7 @@ desc[] =
 
 static void xsane_batch_scan_get_parameters(Batch_Scan_Parameters *parameters)
 {
- char buf[255];
+ char buf[TEXTBUFSIZE];
  SANE_Int unit;
 
   DBG(DBG_proc, "xsane_batch_scan_get_parameters\n");
@@ -336,7 +336,7 @@ int xsane_batch_scan_load_list_from_file(char *filename)
 static void xsane_batch_scan_load_list(void)
 {
  char filename[PATH_MAX];
- char windowname[256];
+ char windowname[TEXTBUFSIZE];
 
   DBG(DBG_proc, "xsane_batch_scan_load_list\n");
 
@@ -349,7 +349,7 @@ static void xsane_batch_scan_load_list(void)
   {
     if (xsane_batch_scan_load_list_from_file(filename)) /* error while loading file ? */
     {
-     char buf[256];
+     char buf[TEXTBUFSIZE];
 
       snprintf(buf, sizeof(buf), "%s `%s': %s", ERR_OPEN_FAILED, filename, strerror(errno));
       xsane_back_gtk_error(buf, TRUE);
@@ -387,7 +387,7 @@ static void xsane_batch_scan_save_list(void)
  int fd;
  Wire w;
  char filename[PATH_MAX];
- char windowname[256];
+ char windowname[TEXTBUFSIZE];
 
   DBG(DBG_proc, "xsane_batch_scan_save_list\n");
 
@@ -429,7 +429,7 @@ static void xsane_batch_scan_save_list(void)
     }
     else
     {
-     char buf[256];
+     char buf[TEXTBUFSIZE];
 
       snprintf(buf, sizeof(buf), "%s `%s': %s", ERR_OPEN_FAILED, filename, strerror(errno));
       xsane_back_gtk_error(buf, TRUE);
@@ -447,7 +447,7 @@ static void xsane_batch_scan_scan_list(void)
  GList *list = GTK_LIST(xsane.batch_scan_list)->children;
  Batch_Scan_Parameters *parameters = NULL;
  SANE_Int val_start = SANE_TRUE;
- SANE_Int val_loop  = SANE_TRUE;
+ SANE_Int val_loop  = BATCH_MODE_LOOP;
  SANE_Int val_end   = SANE_FALSE;
  SANE_Word val_next_tl_y = SANE_FIX(0.0);
 
@@ -463,7 +463,7 @@ static void xsane_batch_scan_scan_list(void)
   {
     if (!list->next) /* last scan */
     {
-      val_loop = SANE_FALSE;
+      val_loop = BATCH_MODE_LAST_SCAN;
       val_end  = SANE_TRUE;
       val_next_tl_y = SANE_FIX(0.0);
     }
@@ -501,7 +501,7 @@ static void xsane_batch_scan_scan_list(void)
       gtk_main_iteration();
     }
 
-    xsane_scan_dialog();
+    xsane_scan_dialog(NULL);
 
     while (xsane.scanning)
     {
@@ -533,7 +533,7 @@ static void xsane_batch_scan_scan_list(void)
   xsane_control_option(xsane.dev, xsane.well_known.batch_scan_end, SANE_ACTION_SET_VALUE, &val_end, NULL);
   xsane_control_option(xsane.dev, xsane.well_known.batch_scan_next_tl_y, SANE_ACTION_SET_VALUE, &val_next_tl_y, NULL);
 
-  xsane.batch_loop = FALSE; /* make sure we reset the batch scan loop flag */
+  xsane.batch_loop = BATCH_MODE_OFF; /* make sure we reset the batch scan loop flag */
 
   if (parameters)
   {
@@ -561,7 +561,11 @@ static void xsane_batch_scan_scan_selected(void)
       xsane_batch_scan_establish_parameters(parameters, TRUE);
     }
 
-    xsane_scan_dialog();
+    xsane.batch_loop = BATCH_MODE_LAST_SCAN; /* to make sure we do not scan multiple times */
+
+    xsane_scan_dialog(NULL);
+
+    xsane.batch_loop = BATCH_MODE_OFF; /* make sure we reset the batch scan loop flag */
   }
 }
 
@@ -595,7 +599,7 @@ static void xsane_batch_scan_delete(void)
 
 static void xsane_batch_scan_update_label(Batch_Scan_Parameters *parameters)
 {
-  char buf[256];
+  char buf[TEXTBUFSIZE];
   const char *unit_str;
   double tl_x = parameters->tl_x;
   double tl_y = parameters->tl_y;
@@ -843,7 +847,7 @@ static void xsane_batch_scan_rename_callback(GtkWidget *widget, gpointer data)
  GtkWidget *text;
  GtkWidget *button;
  GtkWidget *vbox, *hbox;
- char buf[256];
+ char buf[TEXTBUFSIZE];
 
   DBG(DBG_proc, "xsane_batch_scan_rename\n");
 
@@ -939,6 +943,12 @@ static gint xsane_batch_scan_win_delete(GtkWidget *widget, gpointer data)
 {
   DBG(DBG_proc, "xsane_batch_scan_win_delete\n");
 
+  if (preferences.show_batch_scan)
+  {
+    xsane_window_get_position(xsane.batch_scan_dialog, &xsane.batch_dialog_posx, &xsane.batch_dialog_posy);
+    gtk_window_move(GTK_WINDOW(xsane.batch_scan_dialog), xsane.batch_dialog_posx, xsane.batch_dialog_posy);
+  }
+
   gtk_widget_hide(widget);
   preferences.show_batch_scan = FALSE;
   gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(xsane.show_batch_scan_widget), preferences.show_batch_scan);
