@@ -65,7 +65,8 @@ static GtkWidget *xsane_viewer_file_build_menu(Viewer *v);
 static GtkWidget *xsane_viewer_edit_build_menu(Viewer *v);
 static GtkWidget *xsane_viewer_filters_build_menu(Viewer *v);
 static int xsane_viewer_read_image(Viewer *v);
-Viewer *xsane_viewer_new(char *filename, int allow_reduction_to_lineart, char *output_filename, viewer_modification allow_modification);
+Viewer *xsane_viewer_new(char *filename, char *selection_filetype, int allow_reduction_to_lineart,
+                         char *output_filename, viewer_modification allow_modification, int image_saved);
 
 /* ---------------------------------------------------------------------------------------------------------------------- */
 
@@ -162,7 +163,7 @@ static gint xsane_viewer_close_callback(GtkWidget *widget, gpointer data)
 
   if (!v->image_saved)
   {
-   char buf[256];
+   char buf[TEXTBUFSIZE];
 
     snprintf(buf, sizeof(buf), WARN_VIEWER_IMAGE_NOT_SAVED);
     xsane_viewer_set_sensitivity(v, FALSE);
@@ -251,10 +252,10 @@ static void xsane_viewer_save_callback(GtkWidget *window, gpointer data)
  Viewer *v = (Viewer *) data;
  char outputfilename[1024];
  char *inputfilename;
- char windowname[256];
+ char windowname[TEXTBUFSIZE];
  int output_format;
  int abort = 0;
- char buf[256];
+ char buf[TEXTBUFSIZE];
 
   if (v->block_actions) /* actions blocked: return */
   {
@@ -281,7 +282,7 @@ static void xsane_viewer_save_callback(GtkWidget *window, gpointer data)
     snprintf(windowname, sizeof(windowname), "%s %s %s", xsane.prog_name, WINDOW_VIEWER_OUTPUT_FILENAME, xsane.device_text);
  
     umask((mode_t) preferences.directory_umask); /* define new file permissions */
-    abort = xsane_back_gtk_get_filename(windowname, outputfilename, sizeof(outputfilename), outputfilename, &preferences.filetype, TRUE, TRUE, FALSE, TRUE);
+    abort = xsane_back_gtk_get_filename(windowname, outputfilename, sizeof(outputfilename), outputfilename, &v->selection_filetype, TRUE, TRUE, FALSE, TRUE);
     umask(XSANE_DEFAULT_UMASK); /* define new file permissions */ 
 
     if (abort)
@@ -297,16 +298,21 @@ static void xsane_viewer_save_callback(GtkWidget *window, gpointer data)
   }
 
   v->output_filename = strdup(outputfilename);
-  xsane_update_counter_in_filename(&v->output_filename, FALSE, 0, preferences.filename_counter_len); /* set correct counter length */
 
-  if (preferences.overwrite_warning)  /* test if filename already used */
+#if 0
+  /* to be removed */
+  xsane_update_counter_in_filename(&v->output_filename, FALSE, 0, preferences.filename_counter_len); /* set correct counter length */
+#endif
+
+
+  if ((preferences.overwrite_warning) && (!v->keep_viewer_pnm_format))  /* test if filename already used when filename can be changed by user */
   {
    FILE *testfile;
 
     testfile = fopen(v->output_filename, "rb"); /* read binary (b for win32) */
     if (testfile) /* filename used: skip */
     {
-     char buf[256];
+     char buf[TEXTBUFSIZE];
  
       fclose(testfile);
       snprintf(buf, sizeof(buf), WARN_FILE_EXISTS, v->output_filename);
@@ -320,13 +326,14 @@ static void xsane_viewer_save_callback(GtkWidget *window, gpointer data)
 
   inputfilename = strdup(v->filename);
 
-  output_format = xsane_identify_output_format(v->output_filename, preferences.filetype, 0);
+  output_format = xsane_identify_output_format(v->output_filename, v->selection_filetype, 0);
 
-  if ((!v->allow_reduction_to_lineart) && (output_format == XSANE_PNM)) /* save PNM but do not reduce to lineart (if lineart) */
+  if (((!v->allow_reduction_to_lineart) && (output_format == XSANE_PNM)) || /* save PNM but do not reduce to lineart (if lineart) */
+      (v->keep_viewer_pnm_format)) /* we have to make sure that we save in viewer pnm format */
   {
     if (xsane_create_secure_file(v->output_filename)) /* remove possibly existing symbolic links for security */
     {
-     char buf[256];
+     char buf[TEXTBUFSIZE];
 
       snprintf(buf, sizeof(buf), "%s %s %s\n", ERR_DURING_SAVE, ERR_CREATE_SECURE_FILE, v->output_filename);
       xsane_back_gtk_error(buf, TRUE);
@@ -352,7 +359,21 @@ static void xsane_viewer_save_callback(GtkWidget *window, gpointer data)
   snprintf(buf, sizeof(buf), "%s %s - %s", WINDOW_VIEWER, v->last_saved_filename, xsane.device_text);
   gtk_window_set_title(GTK_WINDOW(v->top), buf);
 
-  xsane_update_counter_in_filename(&v->output_filename, preferences.skip_existing_numbers, 1, preferences.filename_counter_len);
+  if (xsane.print_filenames) /* print created filenames to stdout? */
+  {
+    if (v->output_filename[0] != '/') /* relative path */
+    {
+     char pathname[512];
+      getcwd(pathname, sizeof(pathname));
+      printf("XSANE_IMAGE_FILENAME: %s/%s\n", pathname, v->output_filename);
+      fflush(stdout);
+    }
+    else /* absolute path */
+    {
+      printf("XSANE_IMAGE_FILENAME: %s\n", v->output_filename);
+      fflush(stdout);
+    }
+  }
 
   xsane_viewer_set_sensitivity(v, TRUE);
 }
@@ -364,7 +385,7 @@ static void xsane_viewer_ocr_callback(GtkWidget *window, gpointer data)
  Viewer *v = (Viewer *) data;
  char outputfilename[1024];
  char *extensionptr;
- char windowname[256];
+ char windowname[TEXTBUFSIZE];
  int abort = 0;
 
   if (v->block_actions) /* actions blocked: return */
@@ -414,7 +435,7 @@ static void xsane_viewer_ocr_callback(GtkWidget *window, gpointer data)
 static void xsane_viewer_clone_callback(GtkWidget *window, gpointer data)
 {
  Viewer *v = (Viewer *) data;
- char outfilename[256];
+ char outfilename[PATH_MAX];
 
   if (v->block_actions) /* actions blocked: return */
   {
@@ -435,13 +456,13 @@ static void xsane_viewer_clone_callback(GtkWidget *window, gpointer data)
 
   if (v->last_saved_filename)
   {
-   char buf[256];
+   char buf[TEXTBUFSIZE];
     snprintf(buf, sizeof(buf), "%s%s", FILENAME_PREFIX_CLONE_OF, v->last_saved_filename);
-    xsane_viewer_new(outfilename, v->allow_reduction_to_lineart, buf, v->allow_modification);
+    xsane_viewer_new(outfilename, v->selection_filetype, v->allow_reduction_to_lineart, buf, v->allow_modification, IMAGE_NOT_SAVED);
   }
   else
   {
-    xsane_viewer_new(outfilename, v->allow_reduction_to_lineart, NULL, v->allow_modification);
+    xsane_viewer_new(outfilename, v->selection_filetype, v->allow_reduction_to_lineart, NULL, v->allow_modification, IMAGE_NOT_SAVED);
   }
 }
 
@@ -555,7 +576,7 @@ static void xsane_viewer_scale_callback(GtkWidget *window, gpointer data)
  GdkPixmap *pixmap;
  GdkBitmap *mask;
  GtkWidget *pixmapwidget;
- char buf[256];
+ char buf[TEXTBUFSIZE];
  FILE *infile;
  Image_info image_info;
 
@@ -810,7 +831,7 @@ static void xsane_viewer_despeckle_callback(GtkWidget *window, gpointer data)
  GtkWidget *hbox, *vbox;
  GtkWidget *label, *spinbutton, *button;
  GtkAdjustment *adjustment;
- char buf[256];
+ char buf[TEXTBUFSIZE];
 
   if (v->block_actions) /* actions blocked: return */
   {
@@ -904,7 +925,7 @@ static void xsane_viewer_blur_callback(GtkWidget *window, gpointer data)
  GtkWidget *hbox, *vbox;
  GtkWidget *label, *spinbutton, *button;
  GtkAdjustment *adjustment;
- char buf[256];
+ char buf[TEXTBUFSIZE];
 
   if (v->block_actions) /* actions blocked: return */
   {
@@ -1015,7 +1036,7 @@ static void xsane_viewer_undo_callback(GtkWidget *window, gpointer data)
 
   if (v->last_saved_filename)
   {
-   char buf[256];
+   char buf[TEXTBUFSIZE];
     snprintf(buf, sizeof(buf), "%s (%s) - %s", WINDOW_VIEWER, v->last_saved_filename, xsane.device_text);
     gtk_window_set_title(GTK_WINDOW(v->top), buf);
   }
@@ -1030,7 +1051,7 @@ static void xsane_viewer_scale_image(GtkWidget *window, gpointer data)
 {
  FILE *outfile;
  FILE *infile;
- char outfilename[256];
+ char outfilename[PATH_MAX];
  Viewer *v = (Viewer *) data;
  Image_info image_info;
 
@@ -1098,7 +1119,7 @@ static void xsane_viewer_scale_image(GtkWidget *window, gpointer data)
 
   if (v->last_saved_filename)
   {
-   char buf[256];
+   char buf[TEXTBUFSIZE];
     snprintf(buf, sizeof(buf), "%s (%s) - %s", WINDOW_VIEWER, v->last_saved_filename, xsane.device_text);
     gtk_window_set_title(GTK_WINDOW(v->top), buf);
   }
@@ -1112,7 +1133,7 @@ static void xsane_viewer_despeckle_image(GtkWidget *window, gpointer data)
 {
  FILE *outfile;
  FILE *infile;
- char outfilename[256];
+ char outfilename[PATH_MAX];
  Viewer *v = (Viewer *) data;
  Image_info image_info;
 
@@ -1175,7 +1196,7 @@ static void xsane_viewer_despeckle_image(GtkWidget *window, gpointer data)
 
   if (v->last_saved_filename)
   {
-   char buf[256];
+   char buf[TEXTBUFSIZE];
     snprintf(buf, sizeof(buf), "%s (%s) - %s", WINDOW_VIEWER, v->last_saved_filename, xsane.device_text);
     gtk_window_set_title(GTK_WINDOW(v->top), buf);
   }
@@ -1189,7 +1210,7 @@ static void xsane_viewer_blur_image(GtkWidget *window, gpointer data)
 {
  FILE *outfile;
  FILE *infile;
- char outfilename[256];
+ char outfilename[PATH_MAX];
  Viewer *v = (Viewer *) data;
  Image_info image_info;
 
@@ -1252,7 +1273,7 @@ static void xsane_viewer_blur_image(GtkWidget *window, gpointer data)
 
   if (v->last_saved_filename)
   {
-   char buf[256];
+   char buf[TEXTBUFSIZE];
     snprintf(buf, sizeof(buf), "%s (%s) - %s", WINDOW_VIEWER, v->last_saved_filename, xsane.device_text);
     gtk_window_set_title(GTK_WINDOW(v->top), buf);
   }
@@ -1266,7 +1287,7 @@ static void xsane_viewer_rotate(Viewer *v, int rotation)
 {
  FILE *outfile;
  FILE *infile;
- char outfilename[256];
+ char outfilename[PATH_MAX];
  Image_info image_info;
 
   if (v->block_actions) /* actions blocked: return */
@@ -1342,7 +1363,7 @@ static void xsane_viewer_rotate(Viewer *v, int rotation)
 
   if (v->last_saved_filename)
   {
-   char buf[256];
+   char buf[TEXTBUFSIZE];
     snprintf(buf, sizeof(buf), "%s (%s) - %s", WINDOW_VIEWER, v->last_saved_filename, xsane.device_text);
     gtk_window_set_title(GTK_WINDOW(v->top), buf);
   }
@@ -1642,7 +1663,7 @@ static int xsane_viewer_read_image(Viewer *v)
  int pos0;
  FILE *infile;
  Image_info image_info;
- char buf[256];
+ char buf[TEXTBUFSIZE];
  float size;
  char *size_unit;
  int width, height;
@@ -1783,6 +1804,11 @@ static int xsane_viewer_read_image(Viewer *v)
     size *= 2.0;
   }
 
+  if (image_info.reduce_to_lineart)
+  {
+    size /= 8.0;
+  }
+
   size_unit = "B";
 
   if (size >= 1024 * 1024)
@@ -1796,7 +1822,7 @@ static int xsane_viewer_read_image(Viewer *v)
     size_unit = "KB";
   }
 
-  if (v->allow_reduction_to_lineart)
+  if (image_info.reduce_to_lineart)
   {
     snprintf(buf, sizeof(buf), TEXT_VIEWER_IMAGE_INFO, image_info.image_width, image_info.image_height, 1, image_info.colors, 
              image_info.resolution_x, image_info.resolution_y, size, size_unit);
@@ -1841,9 +1867,10 @@ static int xsane_viewer_read_image(Viewer *v)
 
 /* ---------------------------------------------------------------------------------------------------------------------- */
 
-Viewer *xsane_viewer_new(char *filename, int allow_reduction_to_lineart, char *output_filename, viewer_modification allow_modification)
+Viewer *xsane_viewer_new(char *filename, char *selection_filetype, int allow_reduction_to_lineart,
+                         char *output_filename, viewer_modification allow_modification, int image_saved)
 {
- char buf[256];
+ char buf[TEXTBUFSIZE];
  Viewer *v;
  GtkWidget *vbox, *hbox;
  GtkWidget *menubar, *menubar_item;
@@ -1866,14 +1893,25 @@ Viewer *xsane_viewer_new(char *filename, int allow_reduction_to_lineart, char *o
   v->undo_filename = NULL;
   v->allow_reduction_to_lineart = allow_reduction_to_lineart;
   v->zoom = 1.0;
-  v->image_saved = FALSE;
+  v->image_saved = image_saved;
+  v->keep_viewer_pnm_format = FALSE;
   v->allow_modification = allow_modification;
   v->next_viewer = xsane.viewer_list;
+  if (selection_filetype)
+  {
+    v->selection_filetype = strdup(selection_filetype);
+  }
+  else
+  {
+    v->selection_filetype = NULL;
+  }
+
   xsane.viewer_list = v;
 
-  if (v->allow_modification == VIEWER_NO_MODIFICATION)
+  if (v->allow_modification != VIEWER_FULL_MODIFICATION)
   {
-    v->image_saved = TRUE;
+    v->keep_viewer_pnm_format = TRUE;
+    v->last_saved_filename = strdup(output_filename); /* output_filename MUST be defined in this case */
   }
 
   if (output_filename)
